@@ -88,6 +88,13 @@ struct _ChamplainMapSourcePrivate
   ChamplainMapProjection map_projection;
 };
 
+static void
+real_fill_tile (ChamplainMapSource *map_source,
+    ChamplainTile *tile)
+{
+  g_error ("Should not be reached");
+}
+
 static void
 champlain_map_source_get_property (GObject *object,
     guint prop_id,
@@ -175,6 +182,7 @@ champlain_map_source_finalize (GObject *object)
   ChamplainMapSource *map_source = CHAMPLAIN_MAP_SOURCE (object);
   ChamplainMapSourcePrivate *priv = map_source->priv;
 
+  g_free (priv->id);
   g_free (priv->name);
   g_free (priv->license);
   g_free (priv->license_uri);
@@ -193,7 +201,7 @@ champlain_map_source_class_init (ChamplainMapSourceClass *klass)
   object_class->get_property = champlain_map_source_get_property;
   object_class->set_property = champlain_map_source_set_property;
 
-  klass->fill_tile = champlain_map_source_real_fill_tile;
+  klass->fill_tile = real_fill_tile;
 
   /**
   * ChamplainMapSource:id:
@@ -481,13 +489,6 @@ champlain_map_source_fill_tile (ChamplainMapSource *map_source,
   CHAMPLAIN_MAP_SOURCE_GET_CLASS (map_source)->fill_tile (map_source, tile);
 }
 
-void
-champlain_map_source_real_fill_tile (ChamplainMapSource *map_source,
-    ChamplainTile *tile)
-{
-  g_error ("Should not be reached");
-}
-
 /**
  * champlain_map_source_get_longitude:
  * @map_source: a #ChamplainMapSource
